
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.031.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Determine how quickly your pull request might get merged",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "GitHub-MergeVelocity",
  "dist_version" => "0.000006",
  "license" => "perl",
  "module_name" => "GitHub::MergeVelocity",
  "recommends" => {
    "CHI" => 0,
    "LWP::ConsoleLogger" => "0.000013",
    "WWW::Mechanize::Cached" => "1.46"
  },
  "recursive_test_files" => 1,
  "requires" => {
    "CLDR::Number::Format::Percent" => 0,
    "DateTime" => 0,
    "DateTime::Format::ISO8601" => 0,
    "File::HomeDir" => 0,
    "Math::Round" => 0,
    "Module::Runtime" => 0,
    "Moo" => 0,
    "MooX::HandlesVia" => 0,
    "MooX::Options" => 0,
    "MooX::StrictConstructor" => 0,
    "Path::Tiny" => 0,
    "Pithub::PullRequests" => 0,
    "Text::SimpleTable::AutoWidth" => "0.09",
    "Type::Library" => 0,
    "Type::Utils" => 0,
    "Types::Standard" => 0,
    "URI" => 0,
    "WWW::Mechanize::GZip" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/github-mergevelocity"
  ],
  "test_requires" => {
    "Test::Most" => 0,
    "Test::RequiresInternet" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::Most" => 0,
  "Test::RequiresInternet" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
